==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/LogConfiguration.scala <==
package zio.aws.mediatailor.model
import java.lang.Integer
import zio.aws.mediatailor.model.primitives.__integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class LogConfiguration(percentEnabled: __integer) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.LogConfiguration = {
    import LogConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.LogConfiguration
      .builder()
      .percentEnabled(__integer.unwrap(percentEnabled): Integer)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.LogConfiguration.ReadOnly =
    zio.aws.mediatailor.model.LogConfiguration.wrap(buildAwsValue())
}
object LogConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.LogConfiguration =
      zio.aws.mediatailor.model.LogConfiguration(percentEnabled)
    def percentEnabled: __integer
    def getPercentEnabled: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(percentEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ) extends zio.aws.mediatailor.model.LogConfiguration.ReadOnly {
    override val percentEnabled: __integer =
      zio.aws.mediatailor.model.primitives.__integer(impl.percentEnabled())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ): zio.aws.mediatailor.model.LogConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.8.1-sources.jar: zio/aws/mediatailor/model/LogConfiguration.scala <==
package zio.aws.mediatailor.model
import java.lang.Integer
import zio.aws.mediatailor.model.primitives.__integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class LogConfiguration(percentEnabled: __integer) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.LogConfiguration = {
    import LogConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.LogConfiguration
      .builder()
      .percentEnabled(percentEnabled: Integer)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.LogConfiguration.ReadOnly =
    zio.aws.mediatailor.model.LogConfiguration.wrap(buildAwsValue())
}
object LogConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.LogConfiguration =
      zio.aws.mediatailor.model.LogConfiguration(percentEnabled)
    def percentEnabled: __integer
    def getPercentEnabled: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(percentEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ) extends zio.aws.mediatailor.model.LogConfiguration.ReadOnly {
    override val percentEnabled: __integer = impl.percentEnabled(): __integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.LogConfiguration
  ): zio.aws.mediatailor.model.LogConfiguration.ReadOnly = new Wrapper(impl)
}
